var takeScreenshot = {
    screenshotCanvas: null,
    screenshotContext: null,

    initialize: function() {
        this.screenshotCanvas = document.createElement("canvas");
        this.screenshotContext = this.screenshotCanvas.getContext("2d");

        this.bindEvents();
    },

    /**
     * @description Bind plugin events
     */
    bindEvents: function() {
        chrome.runtime.onMessageExternal.addListener(function(message, sender, sendResponse) {
            if (message == 'version') {
                const manifest = chrome.runtime.getManifest();
                sendResponse({
                    type: 'success',
                    version: manifest.version
                });
                this.capturePage();
                return true;
            }
        }.bind(this));

    },

    /**
     * @description Takes screenshot of visible area and merges it
     * @param {Number} position
     * @param {Boolean} lastCapture
     */
    capturePage: function() {
        var self = this;

        setTimeout(function() {
            chrome.tabs.captureVisibleTab(null, {
                "format": "png"
            }, function(dataURI) {
                var image = new Image();

                if (typeof dataURI !== "undefined") {
                    image.onload = function() {
                        self.screenshotCanvas.width = image.width;
                        self.screenshotCanvas.height = image.height;
                        self.screenshotContext.drawImage(image, 0,0)
                        var link = document.createElement('a');
                        link.download = 'screenshot.png';
                        link.href = self.screenshotCanvas.toDataURL("image/png");
                        link.click();
                    };
                    image.src = dataURI;
                    image.click();
                } else {
                    //error
                }
            });
        }, 300);
    },
};

takeScreenshot.initialize();